==> cli-1.1.8.tgz: package/config/webpack.project.start.js <==
process.env.NODE_ENV = 'development';
const WebpackDevServer = require('webpack-dev-server');
const Webpack = require('webpack');
const chalk = require('chalk');
const { getWebpackConfig } = require('./project.config.js');
var path = require('path');
const projectRoot = process.cwd();
const ProgressBarPlugin = require('progress-bar-webpack-plugin');

// 获取命令中的port参数
const argv = process.argv;
let configFile = 'runner.config.js';
let port = 2225;
argv.map(item => {
  if (item.indexOf('port=') >= 0) {
    let newPort = item.replace('port=', '');
    if (newPort.match(/^\d\d\d\d$/)) {
      port = parseInt(newPort, 10);
    }
  }
  else if(item.indexOf('config=') >= 0) {
    configFile = item.replace('config=', '');
  }
});

//
let runnerConfigPath = '';
try{
  runnerConfigPath = require.resolve(path.resolve(projectRoot, 'node_modules',configFile));
}
catch(e) {
  try{
    runnerConfigPath = require.resolve(path.resolve(projectRoot, configFile));
  }
  catch(e) {

  }
}

// 加载config文件
const runnerConfig = require(runnerConfigPath);
const layoutRoot = runnerConfig.layoutRoot || path.join(__dirname, '../template/release/src');
const outputPath = path.resolve(projectRoot, runnerConfig.outputPath);


// 根据配置文件，获取webpack配置信息
const projectConfig = getWebpackConfig({
  command: 'start',
  layoutRoot,
  projectRoot,
  // devtool: 'eval-source-map',
  entry: {
    index: path.resolve(layoutRoot, 'index.js'),
  },
  publicPath: '/',//runnerConfig.publicPath,
  webpackConfig: runnerConfig.webpackConfig,
  outputPath: outputPath,
  lessVariables: runnerConfig.lessVariables || {},
  templatePath:
    runnerConfig.templatePath || path.resolve(__dirname, '../template/release/src/index.ejs'),
  requirePath: path.resolve(__dirname, '../template/release/src/utils/request.js'),
  devServer: {
    contentBase: outputPath,
    port: port, // 端口
    open: true, // 自动打开浏览器
    hot: true, // 开启热更新
    disableHostCheck: true,
    proxy: {},
    historyApiFallback: true,
    publicPath: '/',
    headers: {
      'Access-Control-Allow-Origin': '*',
    },
  },
  isBundleAnalyzerPlugin: runnerConfig.isBundleAnalyzerPlugin,
  isPxToRem: runnerConfig.isPxToRem,
});

projectConfig.plugins.splice(
  0,
  0,
  new ProgressBarPlugin({
    format: 'build [:bar] :percent (:elapsed seconds)',
    clear: false,
    width: 60,
  }),
);

//
const compiler = Webpack(projectConfig);
const server = new WebpackDevServer(compiler, projectConfig.devServer);

server.listen(projectConfig.devServer.port, '0.0.0.0', () => {
  console.log('');
  console.log(chalk.green('server start =', `http://127.0.0.1:${projectConfig.devServer.port}`));
  console.log('');
});

==> cli-1.1.9.tgz: package/config/webpack.project.start.js <==
process.env.NODE_ENV = 'development';
const WebpackDevServer = require('webpack-dev-server');
const webpack = require('webpack');
const chalk = require('chalk');
const { getWebpackConfig } = require('./project.config.js');
var path = require('path');
const projectRoot = process.cwd();
const ProgressBarPlugin = require('progress-bar-webpack-plugin');

// 获取命令中的port参数
const argv = process.argv;
let configFile = 'runner.config.js';
let port = 2225;
argv.map(item => {
  if (item.indexOf('port=') >= 0) {
    let newPort = item.replace('port=', '');
    if (newPort.match(/^\d\d\d\d$/)) {
      port = parseInt(newPort, 10);
    }
  }
  else if(item.indexOf('config=') >= 0) {
    configFile = item.replace('config=', '');
  }
});

//
let runnerConfigPath = '';
try{
  runnerConfigPath = require.resolve(path.resolve(projectRoot, 'node_modules',configFile));
}
catch(e) {
  try{
    runnerConfigPath = require.resolve(path.resolve(projectRoot, configFile));
  }
  catch(e) {

  }
}

// 加载config文件
const runnerConfig = require(runnerConfigPath);
const layoutRoot = runnerConfig.layoutRoot || path.join(__dirname, '../template/release/src');
const outputPath = path.resolve(projectRoot, runnerConfig.outputPath);


// 根据配置文件，获取webpack配置信息
const projectConfig = getWebpackConfig({
  command: 'start',
  layoutRoot,
  projectRoot,
  // devtool: 'eval-source-map',
  entry: {
    index: path.resolve(layoutRoot, 'index.js'),
  },
  publicPath: '/',//runnerConfig.publicPath,
  webpackConfig: runnerConfig.webpackConfig,
  outputPath: outputPath,
  lessVariables: runnerConfig.lessVariables || {},
  templatePath:
    runnerConfig.templatePath || path.resolve(__dirname, '../template/release/src/index.ejs'),
  requirePath: path.resolve(__dirname, '../template/release/src/utils/request.js'),
  devServer: {
    // -- webpack-dev-server@4.11.1 --
    // port: port, // 端口
    // open: true, // 自动打开浏览器
    // hot: true, // 开启热更新
    // proxy: {},
    // historyApiFallback: true,
    // headers: [{
    //   key: 'Access-Control-Allow-Origin',
    //   value: '*'
    // }],
    // allowedHosts: 'all',
    // client: {
    //   overlay: false,
    //   progress: true,

    // },

    contentBase: outputPath,
    port: port, // 端口
    open: true, // 自动打开浏览器
    hot: true, // 开启热更新
    disableHostCheck: true,
    proxy: {},
    historyApiFallback: true,
    publicPath: '/',
    headers: {
      'Access-Control-Allow-Origin': '*',
    },
  },
  isBundleAnalyzerPlugin: runnerConfig.isBundleAnalyzerPlugin,
  isPxToRem: runnerConfig.isPxToRem,
});

projectConfig.cache = true;
projectConfig.watch = true;
projectConfig.watchOptions = {
  aggregateTimeout: 200,
};
projectConfig.plugins.splice(
  0,
  0,
  new ProgressBarPlugin({
    format: 'build [:bar] :percent (:elapsed seconds)',
    clear: false,
    width: 60,
  }),
);

//
const compiler = webpack(projectConfig);
// -- webpack-dev-server@4.11.1 --
// const server = new WebpackDevServer(projectConfig.devServer, compiler);
const server = new WebpackDevServer(compiler, projectConfig.devServer);

server.listen(projectConfig.devServer.port, '0.0.0.0', () => {
  console.log('');
  console.log(chalk.green('server start =', `http://127.0.0.1:${projectConfig.devServer.port}`));
  console.log('');
});
